@@ -1,6 +1,6 @@
 # coding: utf-8
 
-license = """ MIT License
+LICENSE = """ MIT License
 
 Copyright (c) 2020-2021 hrp/hrpzcf <hrpzcf@foxmail.com>
 
@@ -23,21 +23,29 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 __all__ = [
+    "AUTHOR",
     "all_py_paths",
+    "Command",
     "cur_py_path",
-    "index_urls",
-    "license",
-    "ParamTypeError",
-    "ParamValueError",
-    "parse_package_names",
-    "PathParamError",
-    "PyEnv",
-    "UnsupportedPlatform",
-    "VERSION",
+    "execute_commands",
+    "LICENSE",
+    "NAME",
     "PipInformation",
+    "PyEnv",
+    "parse_package_names",
+    "VERNUM",
+    "VERSION",
+    "WEBSITE",
+    "index_urls",
 ]
 
 from .__version__ import *
-from .core.fastpip import PipInformation, PyEnv, index_urls, parse_package_names
-from .errors.errors import *
+from .core.fastpip import (
+    PipInformation,
+    PyEnv,
+    execute_commands,
+    index_urls,
+    parse_package_names,
+)
+from .utils.cmdutil import Command
 from .utils.findpath import all_py_paths, cur_py_path
