@@ -1,10 +1,9 @@
 # coding: utf-8
 
-__all__ = ["NAME", "AUTHOR", "EMAIL", "WEBSITE", "VERSION", "VERNUM"]
+__all__ = ["NAME", "AUTHOR", "WEBSITE", "VERSION", "VERNUM"]
 
 NAME = "fastpip"
-VERNUM = 0, 14, 1
+VERNUM = 1, 5, 0
 AUTHOR = "hrpzcf"
-EMAIL = "hrpzcf@foxmail.com"
 WEBSITE = "https://github.com/hrpzcf/fastpip"
 VERSION = ".".join(map(str, VERNUM))
